#include "simpletools.h"
#include "abdrive.h"
#include "wifi.h"
#include "ping.h"
#include "fdserial.h"

void prox();  //Proximity Sensor Process

#define emicRx 3    // Prop pin 6
#define emicTx 2    // Prop pin 7
fdserial *emic;

int event, id, handle;
int wsId, wsHandle = 0;
int navChar, buttonCmd, buttonCmdPrev; 
int val, speedVal, speedLeft, speedRight;
int irLeft, irRight; 
int distance;
int stop;
int ltick;
int rtick;
int oL = 0;
int oR = 0;

int main()
{
  int *cog = cog_run(prox, 128);
  emic = fdserial_open(emicRx, emicTx, 0, 9600);    // parameters (prop Rx pin, prop tx pin, mode, baud)
  
  // ****** Clear EMIC2 ******  send terminator and wait until ready.
  // *** The following 3 options for sending the terminator work
       // dprinti(emic,"\n"); 
       //fdserial_txChar(emic,13);   
  writeChar(emic,NL);                 // note: NL is a library defined constant for newline       
  // *** end of 3 options that work.  Using the third option.

  // *** A couple of options that work for waiting until EMIC2 is ready
       //while(fdserial_rxChar(emic) != ':');   
  while(readChar(emic) != ':');   // wait for emic2 to send ready (:) use either ascii (58) or ':'
  // *** end of 2 options that work.  Using second option
  // ****** end of initial clearing ******


  // Set voice
  dprinti(emic,"N4");   // voices 0 through 8  see manual. 4, 6

  writeChar(emic,NL); 
  while(readChar(emic) != ':');
  
  
  const char *emote[10];
  emote[0] = "blah";
  emote[1] = "S Hello!";
  emote[2] = "S Get out of my way!";
  emote[3] = "S I am a crab. Pinch.";
  emote[4] = "S Boop.";
  emote[5] = "S Time to go Tookeo Drift style.";
  emote[6] = "S Waaallleeee.";
  emote[7] = "S I am R 2 D 2. Beep Boop.";
  emote[8] = "S Lets go faster!";
  emote[9] = "S Bet you cant catch me!";
  
  stop = 0;
  ltick = 0;
  rtick = 0;
  
  int *L = &ltick;
  int *R = &rtick;
  
  wifi_start(31, 30, 115200, WX_ALL_COM);

  wsId = wifi_listen(WS, "/ws/a");
  print("wsId = %d\n", wsId);
  print("Ready for Server Connection\n");
  while(1)
  {
    wifi_poll(&event, &id, &handle); 
    //print("event = %c, id = %d, handle = %d\r", event, id, handle);

    if(event == 'W')
    {
      if(id == wsId)
      {
        wsHandle = handle;
        print("wsHandle = %d\n\n", wsHandle);
      }        
    }
    else if(event == 'D')
    {
      print("Incoming websocket data\r");
      wifi_scan(WS, handle, "%c%d", &buttonCmd, &val); //Data read: Letter instruction, speed number(or emote number)
      print("direction: %c, speed: %d\n", buttonCmd, val);
      if(buttonCmd == 'E'){
        dprinti(emic, emote[val]);
        writeChar(emic,NL);
      }
      else{        
        speedVal = val;
      }      
      if(buttonCmd == 'v')
      {
        buttonCmd = buttonCmdPrev;
        speedVal = val;
      }        
      else 
      {
        buttonCmdPrev = buttonCmd;
      }        
    }
    
    if(stop == 1){              //ping sensor detects obstacle ahead
      print("Obstacle detected. Current drive mode: %c\n", buttonCmdPrev);
      if(buttonCmdPrev == 'F'){
        buttonCmd = 'S';
        drive_speed(0,0);
      }        
    }       
    
    if(wsHandle != 0)
    {
      drive_getTicks(L, R);
      wifi_print(WS, wsHandle, "%d:%d:%d", stop, ltick, rtick);
    }       

    if(buttonCmd != 0)
    {//Given movement instructions.
      switch(buttonCmd)
      {
        case 'F': //Foreward
          speedLeft = speedVal;
          speedRight = speedVal;
          break;
        case 'L'://Swivel Turn Left
          speedLeft = -speedVal;
          speedRight = speedVal;
          break;
        case 'R'://Swivel Turn Right
          speedLeft = speedVal;
          speedRight = -speedVal;
          break;
        case 'B'://Backwards
          speedLeft = -speedVal;
          speedRight = -speedVal;
          break;
        case 'S'://Full Stop
          speedLeft = 0;
          speedRight = 0;
          break;
      } 

      //print("speedLeft: %d, speedRight: %d\r", speedLeft, speedRight);
      drive_speed(speedLeft, speedRight);
      buttonCmd = 0;
    }            

    pause(50);
  }    
}

void prox()
{
  while(1){
   distance = ping_cm(8);                    // Get cm distance from Ping)))
  if(distance <= 17){
   freqout(11, 500, 1000); 
   dprinti(emic, "S Something is in my way.");
   writeChar(emic,NL);
   stop = 1;                //set stop bool to true
  }    
  else
  stop = 0;                 //set stop bool to false
  pause(100);
  }     
}  
